@@ -3,9 +3,9 @@
 guidata
 =======
 
-Based on the Qt library (``PyQt4``, ``PyQt5`` and ``PySide2`` are currently supported), 
-`guidata` is a Python library generating graphical user interfaces for easy dataset 
-editing and display. It also provides helpers and application development tools for Qt.
+Based on the Qt library `guidata` is a Python library generating graphical
+user interfaces for easy dataset editing and display. It also provides helpers
+and application development tools for Qt.
 
 External resources:
     * Python Package Index: `PyPI`_
@@ -17,7 +17,12 @@ External resources:
 .. _GoogleGroup: http://groups.google.fr/group/guidata_guiqwt
 """
 
-__version__ = "1.8.0"
+__version__ = "2.0.2"
+
+# TODO: Add Python module hash utilities (for dependencies checking)
+# TODO: Investigate the qthelpers test failure (see after if __name__=='__main__')
+# TODO: Add support for PyQt6
+# TODO: Add support for PySide6
 
 # Dear (Debian, RPM, ...) package makers, please feel free to customize the
 # following path to module's data (images) and translations:
@@ -551,6 +556,7 @@ def qapplication():
     if not app:
         app = QApplication([])
     install_translator(app)
+    set_color_mode(app)
     return app
 
 
@@ -571,3 +577,39 @@ def install_translator(qapp):
             QT_TRANSLATOR = qt_translator  # Keep reference alive
     if QT_TRANSLATOR is not None:
         qapp.installTranslator(QT_TRANSLATOR)
+
+
+def set_color_mode(app):
+    """Set color mode (dark or light), depending on OS setting"""
+    from qtpy.QtWidgets import QStyleFactory
+    from qtpy.QtGui import QPalette, QColor
+    from qtpy.QtCore import Qt
+
+    from guidata.external import darkdetect
+
+    if darkdetect.isDark():
+        app.setStyle(QStyleFactory.create("Fusion"))
+        dark_palette = QPalette()
+        dark_color = QColor(45, 45, 45)
+        disabled_color = QColor(127, 127, 127)
+        dpsc = dark_palette.setColor
+        dpsc(QPalette.Window, dark_color)
+        dpsc(QPalette.WindowText, Qt.white)
+        dpsc(QPalette.Base, QColor(18, 18, 18))
+        dpsc(QPalette.AlternateBase, dark_color)
+        dpsc(QPalette.ToolTipBase, Qt.white)
+        dpsc(QPalette.ToolTipText, Qt.white)
+        dpsc(QPalette.Text, Qt.white)
+        dpsc(QPalette.Disabled, QPalette.Text, disabled_color)
+        dpsc(QPalette.Button, dark_color)
+        dpsc(QPalette.ButtonText, Qt.white)
+        dpsc(QPalette.Disabled, QPalette.ButtonText, disabled_color)
+        dpsc(QPalette.BrightText, Qt.red)
+        dpsc(QPalette.Link, QColor(42, 130, 218))
+        dpsc(QPalette.Highlight, QColor(42, 130, 218))
+        dpsc(QPalette.HighlightedText, Qt.black)
+        dpsc(QPalette.Disabled, QPalette.HighlightedText, disabled_color)
+        app.setPalette(dark_palette)
+        app.setStyleSheet(
+            "QToolTip { color: #ffffff; background-color: #2a82da; border: 1px solid white; }"
+        )
