@@ -15,11 +15,15 @@ import os.path as osp
 from guidata.configtools import add_image_module_path, get_translation
 from guidata.userconfig import UserConfig
 
+from guidata.external import darkdetect
+
+IS_DARK = darkdetect.isDark()
+
 APP_PATH = osp.dirname(__file__)
 add_image_module_path("guidata", "images")
 _ = get_translation("guidata")
 
-WINDOWS_MONO_FONTS = ["Consolas", "Courier New"]
+WINDOWS_MONO_FONTS = ["Cascadia Code", "Consolas", "Courier New"]
 
 DEFAULTS = {
     "arrayeditor": {
@@ -27,23 +31,42 @@ DEFAULTS = {
         "font/family/posix": "Bitstream Vera Sans Mono",
         "font/family/mac": "Monaco",
         "font/size": 9,
-        "font/bold": False,
     },
     "dicteditor": {
         "font/family/nt": WINDOWS_MONO_FONTS,
         "font/family/posix": "Bitstream Vera Sans Mono",
         "font/family/mac": "Monaco",
         "font/size": 9,
-        "font/italic": False,
-        "font/bold": False,
     },
     "texteditor": {
         "font/family/nt": WINDOWS_MONO_FONTS,
         "font/family/posix": "Bitstream Vera Sans Mono",
         "font/family/mac": "Monaco",
         "font/size": 9,
-        "font/italic": False,
-        "font/bold": False,
+    },
+    "codeeditor": {
+        "font/family/nt": WINDOWS_MONO_FONTS,
+        "font/family/posix": "Bitstream Vera Sans Mono",
+        "font/family/mac": "Monaco",
+        "font/size": 10,
+    },
+    "internal_console": {
+        "max_line_count": 300,
+        "working_dir_history": 30,
+        "working_dir_adjusttocontents": False,
+        "font/family": WINDOWS_MONO_FONTS,
+        "font/size": 9,
+        "wrap": True,
+        "calltips": True,
+        "cursor/width": 2,
+        "codecompletion/size": (300, 180),
+        "codecompletion/auto": False,
+        "codecompletion/enter_key": True,
+        "codecompletion/case_sensitive": True,
+        "codecompletion/show_single": False,
+        "external_editor/path": "SciTE",
+        "external_editor/gotoline": "-goto:",
+        "light_background": not IS_DARK,
     },
     "color_schemes": {
         "names": [
@@ -58,7 +81,7 @@ DEFAULTS = {
             "solarized/light",
             "solarized/dark",
         ],
-        "selected": "spyder",
+        "default": "spyder/dark" if IS_DARK else "spyder",
         # ---- Emacs ----
         "emacs/name": "Emacs",
         #      Name            Color     Bold  Italic
@@ -100,7 +123,7 @@ DEFAULTS = {
         # ---- Monokai ----
         "monokai/name": "Monokai",
         #      Name              Color     Bold  Italic
-        "monokai/background": "#2a2b24",
+        "monokai/background": "#121212",
         "monokai/currentline": "#484848",
         "monokai/currentcell": "#3d3d3d",
         "monokai/occurrence": "#666666",
@@ -176,7 +199,7 @@ DEFAULTS = {
         # ---- Spyder/Dark ----
         "spyder/dark/name": "Spyder Dark",
         #           Name             Color     Bold  Italic
-        "spyder/dark/background": "#131926",
+        "spyder/dark/background": "#121212",
         "spyder/dark/currentline": "#2b2b43",
         "spyder/dark/currentcell": "#31314e",
         "spyder/dark/occurrence": "#abab67",
@@ -195,7 +218,7 @@ DEFAULTS = {
         # ---- Zenburn ----
         "zenburn/name": "Zenburn",
         #        Name            Color     Bold  Italic
-        "zenburn/background": "#3f3f3f",
+        "zenburn/background": "#121212",
         "zenburn/currentline": "#333333",
         "zenburn/currentcell": "#2c2c2c",
         "zenburn/occurrence": "#7a738f",
@@ -233,7 +256,7 @@ DEFAULTS = {
         # ---- Solarized Dark ----
         "solarized/dark/name": "Solarized Dark",
         #        Name            Color     Bold  Italic
-        "solarized/dark/background": "#002b36",
+        "solarized/dark/background": "#121212",
         "solarized/dark/currentline": "#083f4d",
         "solarized/dark/currentcell": "#073642",
         "solarized/dark/occurrence": "#657b83",
