@@ -9,21 +9,18 @@
 dataset.dataitems
 =================
 
-The ``guidata.dataset.dataitems`` module contains implementation for 
+The ``guidata.dataset.dataitems`` module contains implementation for
 concrete DataItems.
 """
 
-from __future__ import division, unicode_literals
-
 import os
 import re
 import datetime
-import collections
+import collections.abc
 
 from guidata.dataset.datatypes import DataItem, ItemProperty
 from guidata.utils import utf8_to_unicode, add_extension
 from guidata.config import _
-from qtpy.py3compat import to_text_string, is_text_string, TEXT_TYPES
 
 
 class NumericTypeItem(DataItem):
@@ -97,7 +94,6 @@ class NumericTypeItem(DataItem):
 
     def from_string(self, value):
         """Override DataItem method"""
-        value = to_text_string(value)  # necessary if value is a QString
         # String may contains numerical operands:
         if re.match(r"^([\d\(\)\+/\-\*.]|e)+$", value):
             try:
@@ -114,7 +110,7 @@ class FloatItem(NumericTypeItem):
         * default [float]: default value (optional)
         * min [float]: minimum value (optional)
         * max [float]: maximum value (optional)
-        * slider [bool]: if True, shows a slider widget right after the line 
+        * slider [bool]: if True, shows a slider widget right after the line
           edit widget (default is False)
         * step [float]: step between tick values with a slider widget (optional)
         * nonzero [bool]: if True, zero is not a valid value (optional)
@@ -152,7 +148,7 @@ class FloatItem(NumericTypeItem):
         self.set_prop("data", step=step)
 
     def get_value_from_reader(self, reader):
-        """Reads value from the reader object, inside the try...except 
+        """Reads value from the reader object, inside the try...except
         statement defined in the base item `deserialize` method"""
         return reader.read_float()
 
@@ -168,7 +164,7 @@ class IntItem(NumericTypeItem):
         * unit [string]: physical unit (optional)
         * even [bool]: if True, even values are valid, if False,
           odd values are valid if None (default), ignored (optional)
-        * slider [bool]: if True, shows a slider widget right after the line 
+        * slider [bool]: if True, shows a slider widget right after the line
           edit widget (default is False)
         * help [string]: text shown in tooltip (optional)
         * check [bool]: if False, value is not checked (optional, default=True)
@@ -228,7 +224,7 @@ class IntItem(NumericTypeItem):
         return True
 
     def get_value_from_reader(self, reader):
-        """Reads value from the reader object, inside the try...except 
+        """Reads value from the reader object, inside the try...except
         statement defined in the base item `deserialize` method"""
         return reader.read_int()
 
@@ -243,7 +239,7 @@ class StringItem(DataItem):
         * wordwrap [bool]: toggle word wrapping (optional)
     """
 
-    type = TEXT_TYPES
+    type = (str,)
 
     def __init__(self, label, default=None, notempty=None, wordwrap=False, help=""):
         DataItem.__init__(self, label, default=default, help=help)
@@ -259,11 +255,10 @@ class StringItem(DataItem):
 
     def from_string(self, value):
         """Override DataItem method"""
-        # QString -> str
-        return to_text_string(value)
+        return value
 
     def get_value_from_reader(self, reader):
-        """Reads value from the reader object, inside the try...except 
+        """Reads value from the reader object, inside the try...except
         statement defined in the base item `deserialize` method"""
         return reader.read_unicode()
 
@@ -306,7 +301,7 @@ class BoolItem(DataItem):
         self.set_prop("display", text=text)
 
     def get_value_from_reader(self, reader):
-        """Reads value from the reader object, inside the try...except 
+        """Reads value from the reader object, inside the try...except
         statement defined in the base item `deserialize` method"""
         return reader.read_bool()
 
@@ -334,7 +329,7 @@ class ColorItem(StringItem):
         * default [string]: default value (optional)
         * help [string]: text shown in tooltip (optional)
         * check [bool]: if False, value is not checked (optional, default=True)
-    
+
     Color values are encoded as hexadecimal strings or Qt color names
     """
 
@@ -349,7 +344,7 @@ class ColorItem(StringItem):
         return text_to_qcolor(value).isValid()
 
     def get_value_from_reader(self, reader):
-        """Reads value from the reader object, inside the try...except 
+        """Reads value from the reader object, inside the try...except
         statement defined in the base item `deserialize` method"""
         # Using read_str converts `numpy.string_` to `str` -- otherwise,
         # when passing the string to a QColor Qt object, any numpy.string_ will
@@ -450,7 +445,7 @@ class FilesOpenItem(FileSaveItem):
         help="",
         check=True,
     ):
-        if is_text_string(default):
+        if isinstance(default, str):
             default = [default]
         FileSaveItem.__init__(
             self,
@@ -476,7 +471,6 @@ class FilesOpenItem(FileSaveItem):
 
     def from_string(self, value):
         """Override DataItem method"""
-        value = to_text_string(value)
         if value.endswith("']") or value.endswith('"]'):
             value = eval(value)
         else:
@@ -489,9 +483,9 @@ class FilesOpenItem(FileSaveItem):
         writer.write_sequence([fname.encode("utf-8") for fname in value])
 
     def get_value_from_reader(self, reader):
-        """Reads value from the reader object, inside the try...except 
+        """Reads value from the reader object, inside the try...except
         statement defined in the base item `deserialize` method"""
-        return [to_text_string(fname, "utf-8") for fname in reader.read_sequence()]
+        return [fname for fname in reader.read_sequence()]
 
 
 class DirectoryItem(StringItem):
@@ -521,26 +515,26 @@ class ChoiceItem(DataItem):
     Construct a data item for a list of choices.
         * label [string]: name
         * choices [list, tuple or function]: string list or (key, label) list
-          function of two arguments (item, value) returning a list of tuples 
-          (key, label, image) where image is an icon path, a QIcon instance 
+          function of two arguments (item, value) returning a list of tuples
+          (key, label, image) where image is an icon path, a QIcon instance
           or a function of one argument (key) returning a QIcon instance
         * default [-]: default label or default key (optional)
         * help [string]: text shown in tooltip (optional)
         * check [bool]: if False, value is not checked (optional, default=True)
-        * radio [bool]: if True, shows radio buttons instead of a combo box 
+        * radio [bool]: if True, shows radio buttons instead of a combo box
           (default is False)
     """
 
     def __init__(
         self, label, choices, default=FirstChoice, help="", check=True, radio=False
     ):
-        if isinstance(choices, collections.Callable):
+        if isinstance(choices, collections.abc.Callable):
             _choices_data = ItemProperty(choices)
         else:
             _choices_data = []
             for idx, choice in enumerate(choices):
                 _choices_data.append(self._normalize_choice(idx, choice))
-        if default is FirstChoice and not isinstance(choices, collections.Callable):
+        if default is FirstChoice and not isinstance(choices, collections.abc.Callable):
             default = _choices_data[0][0]
         elif default is FirstChoice:
             default = None
@@ -572,7 +566,7 @@ class ChoiceItem(DataItem):
         # print "ShowChoiceWidget:", choices, value
         for choice in choices:
             if choice[0] == value:
-                return to_text_string(choice[1])
+                return str(choice[1])
         else:
             return DataItem.get_string_value(self, instance)
 
@@ -594,7 +588,7 @@ class MultipleChoiceItem(ChoiceItem):
     def horizontal(self, row_nb=1):
         """
         Method to arange choice list horizontally on `n` rows
-        
+
         Example:
         nb = MultipleChoiceItem("Number", ['1', '2', '3'] ).horizontal(2)
         """
@@ -604,7 +598,7 @@ class MultipleChoiceItem(ChoiceItem):
     def vertical(self, col_nb=1):
         """
         Method to arange choice list vertically on `n` columns
-        
+
         Example:
         nb = MultipleChoiceItem("Number", ['1', '2', '3'] ).vertical(2)
         """
@@ -637,10 +631,10 @@ class ImageChoiceItem(ChoiceItem):
     """
     Construct a data item for a list of choices with images
         * label [string]: name
-        * choices [list, tuple or function]: (label, image) list or 
-          (key, label, image) list function of two arguments (item, value) 
-          returning a list of tuples (key, label, image) where image is an 
-          icon path, a QIcon instance or a function of one argument (key) 
+        * choices [list, tuple or function]: (label, image) list or
+          (key, label, image) list function of two arguments (item, value)
+          returning a list of tuples (key, label, image) where image is an
+          icon path, a QIcon instance or a function of one argument (key)
           returning a QIcon instance
         * default [-]: default label or default key (optional)
         * help [string]: text shown in tooltip (optional)
@@ -703,7 +697,7 @@ class FloatArrayItem(DataItem):
             text += " .. " + fmt % v.max()
             text += "]"
         text += " %s" % unit
-        return to_text_string(text)
+        return str(text)
 
     def serialize(self, instance, writer):
         """Serialize this item"""
@@ -711,7 +705,7 @@ class FloatArrayItem(DataItem):
         writer.write_array(value)
 
     def get_value_from_reader(self, reader):
-        """Reads value from the reader object, inside the try...except 
+        """Reads value from the reader object, inside the try...except
         statement defined in the base item `deserialize` method"""
         return reader.read_array()
 
@@ -723,7 +717,7 @@ class ButtonItem(DataItem):
         * callback [function]: function with four parameters (dataset, item, value, parent)
             - dataset [DataSet]: instance of the parent dataset
             - item [DataItem]: instance of ButtonItem (i.e. self)
-            - value [unspecified]: value of ButtonItem (default ButtonItem 
+            - value [unspecified]: value of ButtonItem (default ButtonItem
               value or last value returned by the callback)
             - parent [QObject]: button's parent widget
         * icon [QIcon or string]: icon show on the button (optional)
@@ -731,8 +725,8 @@ class ButtonItem(DataItem):
         * default [unspecified]: default value passed to the callback (optional)
         * help [string]: text shown in button's tooltip (optional)
         * check [bool]: if False, value is not checked (optional, default=True)
-    
-    The value of this item is unspecified but is passed to the callback along 
+
+    The value of this item is unspecified but is passed to the callback along
     with the whole dataset. The value is assigned the callback`s return value.
     """
 
@@ -759,29 +753,7 @@ class DictItem(ButtonItem):
 
     def __init__(self, label, default=None, help="", check=True):
         def dictedit(instance, item, value, parent):
-            try:
-                # Spyder 4
-                from spyder.plugins.variableexplorer.widgets import collectionseditor
-
-                Editor = collectionseditor.CollectionsEditor
-            except ImportError:
-                try:
-                    # Spyder 3.0
-                    from spyder.widgets.variableexplorer import collectionseditor
-
-                    Editor = collectionseditor.CollectionsEditor
-                except ImportError:
-                    try:
-                        # Spyder 3.0-
-                        from spyderlib.widgets.variableexplorer import collectionseditor
-
-                        Editor = collectionseditor.CollectionsEditor
-                    except ImportError:
-                        # Spyder 2
-                        from spyderlib.widgets import dicteditor
-
-                        Editor = dicteditor.DictEditor
-            editor = Editor(parent)
+            editor = CollectionsEditor(parent)
             value_was_none = value is None
             if value_was_none:
                 value = {}
