@@ -9,22 +9,19 @@
 dataset.datatypes
 =================
 
-The ``guidata.dataset.datatypes`` module contains implementation for 
-DataSets (DataSet, DataSetGroup, ...) and related objects (ItemProperty, 
+The ``guidata.dataset.datatypes`` module contains implementation for
+DataSets (DataSet, DataSetGroup, ...) and related objects (ItemProperty,
 ValueProp, ...).
 """
 
 # pylint: disable-msg=W0622
 # pylint: disable-msg=W0212
 
-from __future__ import print_function, unicode_literals
-
 import sys
 import re
-import collections
+import collections.abc
 
 from guidata.utils import utf8_to_unicode, update_dataset
-from qtpy.py3compat import to_text_string, is_text_string, PY2
 
 
 DEBUG_DESERIALIZE = False
@@ -161,7 +158,9 @@ class DataItem(object):
         self._default = default
         self._help = utf8_to_unicode(help)
         self._props = {}  # a dict realm->dict containing realm-specific properties
-        self.set_prop("display", col=0, colspan=None, label=utf8_to_unicode(label))
+        self.set_prop(
+            "display", col=0, colspan=None, row=None, label=utf8_to_unicode(label)
+        )
         self.set_prop("data", check_value=check)
 
     def get_prop(self, realm, name, default=NoDefault):
@@ -195,11 +194,11 @@ class DataItem(object):
         prop.update(kwargs)
         return self
 
-    def set_pos(self, col=0, colspan=None):
+    def set_pos(self, col=0, colspan=None, row=None):
         """
         Set data item's position on a GUI layout
         """
-        self.set_prop("display", col=col, colspan=colspan)
+        self.set_prop("display", col=col, colspan=colspan, row=row)
         return self
 
     def __str__(self):
@@ -240,12 +239,8 @@ class DataItem(object):
         else:
             fmt = self.get_prop_value("display", instance, "format", "%s")
             func = self.get_prop_value("display", instance, "func", lambda x: x)
-            if isinstance(fmt, collections.Callable) and value is not None:
+            if isinstance(fmt, collections.abc.Callable) and value is not None:
                 return fmt(func(value))
-            elif is_text_string(fmt):
-                # This is only necessary with Python 2: converting to unicode
-                fmt = to_text_string(fmt)
-
             if value is not None:
                 text = self.format_string(instance, value, fmt, func)
             else:
@@ -593,10 +588,7 @@ class DataSetMeta(type):
         return type.__new__(cls, name, bases, dct)
 
 
-if PY2:
-    Meta_Py3Compat = DataSetMeta(b"Meta_Py3Compat", (object,), {})
-else:
-    Meta_Py3Compat = DataSetMeta("Meta_Py3Compat", (object,), {})
+Meta_Py3Compat = DataSetMeta("Meta_Py3Compat", (object,), {})
 
 
 class DataSet(Meta_Py3Compat):
