@@ -17,24 +17,13 @@ There is one widget type for each data item type.
 Example: ChoiceWidget <--> ChoiceItem, ImageChoiceItem
 """
 
-from __future__ import print_function, unicode_literals
-
 import os
 import os.path as osp
 import sys
 import numpy
-import collections
+import collections.abc
 import datetime
 
-try:
-    # PyQt4 4.3.3 on Windows (static DLLs) with py2exe installed:
-    # -> pythoncom must be imported first, otherwise py2exe's boot_com_servers
-    #    will raise an exception ("Unable to load DLL [...]") when calling any
-    #    of the QFileDialog static methods (getOpenFileName, ...)
-    import pythoncom
-except ImportError:
-    pass
-
 from qtpy.QtWidgets import (
     QHBoxLayout,
     QGridLayout,
@@ -55,20 +44,14 @@ from qtpy.QtWidgets import (
     QVBoxLayout,
 )
 from qtpy.QtGui import QColor, QIcon, QPixmap
-from qtpy.QtCore import Qt
+from qtpy.QtCore import Qt, Signal
 from qtpy.compat import getexistingdirectory
 
-try:
-    from qtpy.QtCore import QStringList
-except ImportError:
-    # PyQt API#2
-    QStringList = list
-
 from guidata.utils import update_dataset, restore_dataset, utf8_to_unicode
 from guidata.qthelpers import text_to_qcolor, get_std_icon
 from guidata.configtools import get_icon, get_image_layout, get_image_file_path
 from guidata.config import _
-from qtpy.py3compat import to_text_string, is_text_string
+from guidata.widgets.arrayeditor import ArrayEditor
 
 # ========================== <!> IMPORTANT <!> =================================
 #
@@ -82,13 +65,13 @@ from qtpy.py3compat import to_text_string, is_text_string
 
 class AbstractDataSetWidget(object):
     """
-    Base class for 'widgets' handled by `DataSetEditLayout` and it's derived 
+    Base class for 'widgets' handled by `DataSetEditLayout` and it's derived
     classes.
-    
+
     This is a generic representation of an input (or display) widget that
     has a label and one or more entry field.
-    
-    `DataSetEditLayout` uses a registry of *Item* to *Widget* mapping in order 
+
+    `DataSetEditLayout` uses a registry of *Item* to *Widget* mapping in order
     to automatically create a GUI for a `DataSet` structure
     """
 
@@ -96,7 +79,7 @@ class AbstractDataSetWidget(object):
 
     def __init__(self, item, parent_layout):
         """Derived constructors should create the necessary widgets
-        The base class keeps a reference to item and parent 
+        The base class keeps a reference to item and parent
         """
         self.item = item
         self.parent_layout = parent_layout
@@ -166,6 +149,13 @@ class AbstractDataSetWidget(object):
         if self.label:
             self.label.setEnabled(active)
 
+    def notify_value_change(self):
+        """
+        Notify parent layout that widget value has changed
+        """
+        if not self.build_mode:
+            self.parent_layout.widget_value_changed()
+
 
 class GroupWidget(AbstractDataSetWidget):
     """
@@ -182,7 +172,11 @@ class GroupWidget(AbstractDataSetWidget):
         self.layout = QGridLayout()
         EditLayoutClass = parent_layout.__class__
         self.edit = EditLayoutClass(
-            self.group, item.instance, self.layout, item.item.group
+            self.group,
+            item.instance,
+            self.layout,
+            item.item.group,
+            change_callback=self.notify_value_change,
         )
         self.group.setLayout(self.layout)
 
@@ -273,7 +267,7 @@ class LineEditWidget(AbstractDataSetWidget):
     def get(self):
         """Override AbstractDataSetWidget method"""
         value = self.item.get()
-        old_value = to_text_string(self.value())
+        old_value = str(self.value())
         if value is not None:
             if isinstance(value, QColor):  # if item is a ColorItem object
                 value = value.name()
@@ -286,7 +280,7 @@ class LineEditWidget(AbstractDataSetWidget):
     def line_edit_changed(self, qvalue):
         """QLineEdit validator"""
         if qvalue is not None:
-            value = self.item.from_string(to_text_string(qvalue))
+            value = self.item.from_string(str(qvalue))
         else:
             value = None
         if not self.item.check_value(value):
@@ -302,6 +296,7 @@ class LineEditWidget(AbstractDataSetWidget):
                 cb(self.item.instance, self.item.item, value)
                 self.parent_layout.update_widgets(except_this_one=self)
         self.update(value)
+        self.notify_value_change()
 
     def update(self, value):
         """Override AbstractDataSetWidget method"""
@@ -310,11 +305,11 @@ class LineEditWidget(AbstractDataSetWidget):
             cb(value)
 
     def value(self):
-        return to_text_string(self.edit.text())
+        return str(self.edit.text())
 
     def check(self):
         """Override AbstractDataSetWidget method"""
-        value = self.item.from_string(to_text_string(self.edit.text()))
+        value = self.item.from_string(str(self.edit.text()))
         return self.item.check_value(value)
 
 
@@ -335,7 +330,7 @@ class TextEditWidget(AbstractDataSetWidget):
 
     def __get_text(self):
         """Get QTextEdit text, replacing UTF-8 EOL chars by os.linesep"""
-        return to_text_string(self.edit.toPlainText()).replace("\u2029", os.linesep)
+        return str(self.edit.toPlainText()).replace("\u2029", os.linesep)
 
     def get(self):
         """Override AbstractDataSetWidget method"""
@@ -352,6 +347,7 @@ class TextEditWidget(AbstractDataSetWidget):
         else:
             self.edit.setStyleSheet("")
         self.update(value)
+        self.notify_value_change()
 
     def update(self, value):
         """Override AbstractDataSetWidget method"""
@@ -378,8 +374,7 @@ class CheckBoxWidget(AbstractDataSetWidget):
         self.group = self.checkbox
 
         self.store = self.item.get_prop("display", "store", None)
-        if self.store:
-            self.checkbox.stateChanged.connect(self.do_store)
+        self.checkbox.stateChanged.connect(self.state_changed)
 
     def get(self):
         """Override AbstractDataSetWidget method"""
@@ -405,6 +400,11 @@ class CheckBoxWidget(AbstractDataSetWidget):
             self.place_label(layout, row, label_column)
         layout.addWidget(self.group, row, widget_column, row_span, column_span)
 
+    def state_changed(self, state):
+        self.notify_value_change()
+        if self.store:
+            self.do_store(state)
+
     def do_store(self, state):
         self.store.set(self.item.instance, self.item.item, state)
         self.parent_layout.refresh_widgets()
@@ -419,6 +419,7 @@ class DateWidget(AbstractDataSetWidget):
         super(DateWidget, self).__init__(item, parent_layout)
         self.dateedit = self.group = QDateEdit()
         self.dateedit.setToolTip(item.get_help())
+        self.dateedit.dateTimeChanged.connect(lambda value: self.notify_value_change())
 
     def get(self):
         """Override AbstractDataSetWidget method"""
@@ -436,7 +437,7 @@ class DateWidget(AbstractDataSetWidget):
         try:
             return self.dateedit.date().toPyDate()
         except AttributeError:
-            return self.dateedit.dateTime().toPython()  # PySide2
+            return self.dateedit.dateTime().toPython().date()  # PySide
 
 
 class DateTimeWidget(AbstractDataSetWidget):
@@ -449,6 +450,7 @@ class DateTimeWidget(AbstractDataSetWidget):
         self.dateedit = self.group = QDateTimeEdit()
         self.dateedit.setCalendarPopup(True)
         self.dateedit.setToolTip(item.get_help())
+        self.dateedit.dateTimeChanged.connect(lambda value: self.notify_value_change())
 
     def get(self):
         """Override AbstractDataSetWidget method"""
@@ -466,7 +468,7 @@ class DateTimeWidget(AbstractDataSetWidget):
         try:
             return self.dateedit.dateTime().toPyDateTime()
         except AttributeError:
-            return self.dateedit.dateTime().toPython()  # PySide2
+            return self.dateedit.dateTime().toPython()  # PySide
 
 
 class GroupLayout(QHBoxLayout):
@@ -532,6 +534,7 @@ class ColorWidget(HLayoutMixin, LineEditWidget):
             value = color.name()
             self.edit.setText(value)
             self.update(value)
+            self.notify_value_change()
 
 
 class SliderWidget(HLayoutMixin, LineEditWidget):
@@ -628,7 +631,7 @@ class FileWidget(HLayoutMixin, LineEditWidget):
 
     def select_file(self):
         """Open a file selection dialog box"""
-        fname = self.item.from_string(to_text_string(self.edit.text()))
+        fname = self.item.from_string(str(self.edit.text()))
         if isinstance(fname, list):
             fname = osp.dirname(fname[0])
         parent = self.parent_layout.parent
@@ -637,7 +640,7 @@ class FileWidget(HLayoutMixin, LineEditWidget):
         if len(fname) == 0:
             fname = self.basedir
         _formats = self.item.get_prop_value("data", "formats")
-        formats = [to_text_string(format).lower() for format in _formats]
+        formats = [str(format).lower() for format in _formats]
         filter_lines = [
             (_("%s files") + " (*.%s)") % (format.upper(), format) for format in formats
         ]
@@ -656,7 +659,7 @@ class FileWidget(HLayoutMixin, LineEditWidget):
         sys.stdout = _temp
         if fname:
             if isinstance(fname, list):
-                fname = to_text_string(fname)
+                fname = str(fname)
             self.edit.setText(fname)
 
 
@@ -674,7 +677,7 @@ class DirectoryWidget(HLayoutMixin, LineEditWidget):
 
     def select_directory(self):
         """Open a directory selection dialog box"""
-        value = self.item.from_string(to_text_string(self.edit.text()))
+        value = self.item.from_string(str(self.edit.text()))
         parent = self.parent_layout.parent
         child_title = _get_child_title_func(parent)
         dname = getexistingdirectory(parent, child_title(self.item), value)
@@ -715,6 +718,7 @@ class ChoiceWidget(AbstractDataSetWidget):
                 self.parent_layout.update_dataitems()
             cb(self.item.instance, self.item.item, self.value())
             self.parent_layout.update_widgets(except_this_one=self)
+        self.notify_value_change()
 
     def initialize_widget(self):
         if self.is_radio:
@@ -732,11 +736,11 @@ class ChoiceWidget(AbstractDataSetWidget):
             if self.is_radio:
                 button = QRadioButton(lbl, self.group)
             if img:
-                if is_text_string(img):
+                if isinstance(img, str):
                     if not osp.isfile(img):
                         img = get_image_file_path(img)
                     img = QIcon(img)
-                elif isinstance(img, collections.Callable):
+                elif isinstance(img, collections.abc.Callable):
                     img = img(key)
                 if self.is_radio:
                     button.setIcon(img)
@@ -893,21 +897,7 @@ class FloatArrayWidget(AbstractDataSetWidget):
         """Open an array editor dialog"""
         parent = self.parent_layout.parent
         label = self.item.get_prop_value("display", "label")
-        try:
-            # Spyder 4
-            from spyder.plugins.variableexplorer.widgets import arrayeditor
-        except ImportError:
-            try:
-                # Spyder 3.0
-                from spyder.widgets.variableexplorer import arrayeditor
-            except ImportError:
-                # Spyder 3.0-
-                try:
-                    from spyderlib.widgets.variableexplorer import arrayeditor
-                except ImportError:
-                    # Spyder 2
-                    from spyderlib.widgets import arrayeditor
-        editor = arrayeditor.ArrayEditor(parent)
+        editor = ArrayEditor(parent)
         if editor.setup_and_check(self.arr, title=label):
             if editor.exec_():
                 self.update(self.arr)
@@ -982,7 +972,7 @@ class ButtonWidget(AbstractDataSetWidget):
         self.button.setToolTip(item.get_help())
         _icon = self.item.get_prop_value("display", "icon")
         if _icon is not None:
-            if is_text_string(_icon):
+            if isinstance(_icon, str):
                 _icon = get_icon(_icon)
             self.button.setIcon(_icon)
         self.button.clicked.connect(self.clicked)
@@ -1051,7 +1041,7 @@ class DataSetWidget(AbstractDataSetWidget):
     def get_dataset(self):
         """update's internal parameter representation
         from the item's stored value
-        
+
         default behavior uses update_dataset and assumes
         internal dataset class is the same as item's value
         class"""
@@ -1061,7 +1051,7 @@ class DataSetWidget(AbstractDataSetWidget):
     def set_dataset(self):
         """update the item's value from the internal
         data representation
-        
+
         default behavior uses restore_dataset and assumes
         internal dataset class is the same as item's value
         class"""
@@ -1073,4 +1063,3 @@ class DataSetWidget(AbstractDataSetWidget):
     ):
         """Override AbstractDataSetWidget method"""
         layout.addWidget(self.group, row, label_column, row_span, column_span + 1)
-
