@@ -9,8 +9,6 @@
 Reader and Writer for the serialization of DataSets into HDF5 files
 """
 
-from __future__ import print_function
-
 import sys
 from uuid import uuid1
 
@@ -20,8 +18,6 @@ import numpy as np
 from guidata.utils import utf8_to_unicode
 from guidata.userconfigio import BaseIOHandler, WriterMixin
 
-from qtpy.py3compat import PY2, PY3, is_binary_string, to_binary_string, to_text_string
-
 
 class TypeConverter(object):
     def __init__(self, to_type, from_type=None):
@@ -42,19 +38,14 @@ class TypeConverter(object):
         return self._from_type(value)
 
 
-if PY2:
-    unicode_hdf = TypeConverter(lambda x: x.encode("utf-8"), utf8_to_unicode)
-else:
-    unicode_hdf = TypeConverter(
-        lambda x: x.encode("utf-8"), lambda x: to_text_string(x, encoding="utf-8")
-    )
+unicode_hdf = TypeConverter(lambda x: x.encode("utf-8"), lambda x: str(x, "utf-8"))
 int_hdf = TypeConverter(int)
 
 
 class Attr(object):
     """Helper class representing class attribute that
     should be saved/restored to/from a corresponding HDF5 attribute
-    
+
     hdf_name : name of the attribute in the HDF5 file
     struct_name : name of the attribute in the object (default to hdf_name)
     type : attribute type (guess it if None)
@@ -216,7 +207,7 @@ class H5Store(object):
     def generic_load(self, parent, dest, structure):
         """load the data from the file into dest using 'structure'
         as a descriptor.
-        
+
         structure is the same as in generic_save
         """
         for instr in structure:
@@ -268,8 +259,7 @@ class HDF5Writer(HDF5Handler, WriterMixin):
         group = self.get_parent_group()
         group.attrs[self.option[-1]] = val.encode("utf-8")
 
-    if PY3:
-        write_unicode = write_str
+    write_unicode = write_str
 
     def write_array(self, val):
         group = self.get_parent_group()
@@ -290,7 +280,7 @@ class HDF5Writer(HDF5Handler, WriterMixin):
             else:
                 ids = []
                 for obj in seq:
-                    guid = to_binary_string(str(uuid1()))
+                    guid = bytes(str(uuid1()), "utf-8")
                     ids.append(guid)
                     with self.group(guid):
                         if obj is None:
@@ -310,7 +300,7 @@ class HDF5Reader(HDF5Handler):
     def read(self, group_name=None, func=None, instance=None):
         """Read value within current group or group_name.
 
-        Optional argument `instance` is an object which 
+        Optional argument `instance` is an object which
         implements the DataSet-like `deserialize` method."""
         if group_name:
             self.begin(group_name)
@@ -334,7 +324,7 @@ class HDF5Reader(HDF5Handler):
     def read_any(self):
         group = self.get_parent_group()
         value = group.attrs[self.option[-1]]
-        if is_binary_string(value):
+        if isinstance(value, bytes):
             return value.decode("utf-8")
         else:
             return value
@@ -368,10 +358,10 @@ class HDF5Reader(HDF5Handler):
         """Read object sequence in group.
         Objects must implement the DataSet-like `deserialize` method.
         `klass` is the object class which constructor requires no argument.
-        
-        progress_callback: if not None, this function is called with 
-        an integer argument (progress: 0 --> 100). Function returns the 
-        `cancel` state (True: progress dialog has been canceled, False 
+
+        progress_callback: if not None, this function is called with
+        an integer argument (progress: 0 --> 100). Function returns the
+        `cancel` state (True: progress dialog has been canceled, False
         otherwise)
         """
         with self.group(group_name):
