@@ -9,12 +9,10 @@
 qthelpers
 ---------
 
-The ``guidata.qthelpers`` module provides helper functions for developing 
+The ``guidata.qthelpers`` module provides helper functions for developing
 easily Qt-based graphical user interfaces.
 """
 
-from __future__ import print_function
-
 import sys
 import os
 import os.path as osp
@@ -35,17 +33,53 @@ from qtpy.QtWidgets import (
 from qtpy.QtGui import QColor, QIcon, QKeySequence
 from qtpy.QtCore import Qt
 
+
 # Local imports:
+from guidata.external import darkdetect
 from guidata.configtools import get_icon
-from qtpy.py3compat import is_text_string
+
+
+def win32_fix_title_bar_background(widget):
+    """Fix window title bar background for Windows 10+ dark theme"""
+    if os.name != "nt" or not darkdetect.isDark():
+        return
+
+    import ctypes
+    from ctypes import wintypes
+
+    class ACCENTPOLICY(ctypes.Structure):
+        _fields_ = [
+            ("AccentState", ctypes.c_uint),
+            ("AccentFlags", ctypes.c_uint),
+            ("GradientColor", ctypes.c_uint),
+            ("AnimationId", ctypes.c_uint),
+        ]
+
+    class WINDOWCOMPOSITIONATTRIBDATA(ctypes.Structure):
+        _fields_ = [
+            ("Attribute", ctypes.c_int),
+            ("Data", ctypes.POINTER(ctypes.c_int)),
+            ("SizeOfData", ctypes.c_size_t),
+        ]
+
+    accent = ACCENTPOLICY()
+    accent.AccentState = 1  # Default window Blur #ACCENT_ENABLE_BLURBEHIND
+
+    data = WINDOWCOMPOSITIONATTRIBDATA()
+    data.Attribute = 26  # WCA_USEDARKMODECOLORS
+    data.SizeOfData = ctypes.sizeof(accent)
+    data.Data = ctypes.cast(ctypes.pointer(accent), ctypes.POINTER(ctypes.c_int))
+
+    set_win_cpa = ctypes.windll.user32.SetWindowCompositionAttribute
+    set_win_cpa.argtypes = (wintypes.HWND, WINDOWCOMPOSITIONATTRIBDATA)
+    set_win_cpa.restype = ctypes.c_int
+    set_win_cpa(int(widget.winId()), data)
 
 
 def text_to_qcolor(text):
     """Create a QColor from specified string"""
     color = QColor()
-    if not is_text_string(text):  # testing for QString (PyQt API#1)
-        text = str(text)
-    if text.startswith("#") and len(text) == 7:
+    if text is not None and text.startswith("#") and len(text) == 7:
         correct = "#0123456789abcdef"
         for char in text:
             if char.lower() not in correct:
@@ -116,7 +150,7 @@ def create_toolbutton(
     if text is not None:
         button.setText(text)
     if icon is not None:
-        if is_text_string(icon):
+        if isinstance(icon, str):
             icon = get_icon(icon)
         button.setIcon(icon)
     if text is not None or tip is not None:
@@ -243,6 +277,7 @@ class ShowStdIcons(QWidget):
         layout = QHBoxLayout()
         row_nb = 14
         cindex = 0
+        col_layout = QVBoxLayout()
         for child in dir(QStyle):
             if child.startswith("SP_"):
                 if cindex == 0:
@@ -273,7 +308,4 @@ def show_std_icons():
 
 
 if __name__ == "__main__":
-    from guidata.utils import pairs
-
-    print(list(pairs(list(range(5)))))
     show_std_icons()
