@@ -9,12 +9,11 @@
 qtwidgets
 ---------
 
-The ``guidata.qtwidgets`` module provides ready-to-use or generic widgets 
+The ``guidata.qtwidgets`` module provides ready-to-use or generic widgets
 for developing easily Qt-based graphical user interfaces.
 """
 
 from math import cos, sin, pi
-from qtpy import PYQT5
 from qtpy.QtWidgets import QLabel, QWidget, QDockWidget
 from qtpy.QtGui import QPainter, QPen
 from qtpy.QtCore import QSize, Qt
@@ -27,7 +26,7 @@ class RotatedLabel(QLabel):
     """
     Rotated QLabel
     (rich text is not supported)
-    
+
     Arguments:
         * parent: parent widget
         * angle=270 (int): rotation angle in degrees
@@ -71,8 +70,8 @@ class RotatedLabel(QLabel):
         hint = QLabel.sizeHint(self)
         width, height = hint.width(), hint.height()
         angle = self.angle * pi / 180
-        rotated_width = abs(width * cos(angle)) + abs(height * sin(angle))
-        rotated_height = abs(width * sin(angle)) + abs(height * cos(angle))
+        rotated_width = int(abs(width * cos(angle)) + abs(height * sin(angle)))
+        rotated_height = int(abs(width * sin(angle)) + abs(height * cos(angle)))
         return QSize(rotated_width, rotated_height)
 
     def minimumSizeHint(self):
@@ -88,14 +87,18 @@ class DockableWidgetMixin(object):
         | QDockWidget.DockWidgetMovable
     )
 
-    def __init__(self, parent):
-        self.parent_widget = parent
+    def __init__(self):
         self._isvisible = False
         self.dockwidget = None
         self._allowed_areas = self.ALLOWED_AREAS
         self._location = self.LOCATION
         self._features = self.FEATURES
 
+    @property
+    def parent_widget(self):
+        """Return associated QWidget parent"""
+        return self.parent()
+
     def setup_dockwidget(self, location=None, features=None, allowed_areas=None):
         assert (
             self.dockwidget is None
@@ -136,8 +139,5 @@ class DockableWidgetMixin(object):
 
 class DockableWidget(QWidget, DockableWidgetMixin):
     def __init__(self, parent):
-        if PYQT5:
-            super(DockableWidget, self).__init__(parent, parent=parent)
-        else:
-            QWidget.__init__(self, parent)
-            DockableWidgetMixin.__init__(self, parent)
+        QWidget.__init__(self, parent)
+        DockableWidgetMixin.__init__(self)
