@@ -11,27 +11,17 @@
 utils
 -----
 
-The ``guidata.utils`` module provides various utility helper functions 
+The ``guidata.utils`` module provides various utility helper functions
 (pure python).
 """
 
-from __future__ import print_function
-
 import sys
 import time
 import subprocess
 import os
 import os.path as osp
 import locale  # Warning: 2to3 false alarm ('import' fixer)
-import collections
-
-from qtpy.py3compat import (
-    is_unicode,
-    to_text_string,
-    is_text_string,
-    get_func_code,
-    get_func_name,
-)
+import collections.abc
 
 # Local imports
 from guidata.userconfig import get_home_dir
@@ -63,7 +53,7 @@ def add_extension(item, value):
     """Add extension to filename
     `item`: data item representing a file path
     `value`: possible value for data item"""
-    value = to_text_string(value)
+    value = str(value)
     formats = item.get_prop("data", "formats")
     if len(formats) == 1 and formats[0] != "*":
         if not value.endswith("." + formats[0]) and len(value) > 0:
@@ -114,18 +104,10 @@ def decode_fs_string(string):
     return string.decode(charset)
 
 
-# TODO: Py3/I'm really not satisfied with this code even if it's compatible with Py3
 def utf8_to_unicode(string):
-    """Convert UTF-8 string to Unicode"""
-    if not is_text_string(string):
-        string = to_text_string(string)
-    if not is_unicode(string):
-        try:
-            string = to_text_string(string, "utf-8")
-        except UnicodeDecodeError:
-            # This is border line... but we admit here string which has been
-            # erroneously encoded in file system charset instead of UTF-8
-            string = decode_fs_string(string)
+    """Convert UTF-8 string to Unicode str"""
+    if not isinstance(string, str):
+        string = str(string)
     return string
 
 
@@ -203,17 +185,17 @@ def assert_interface_supported(klass, iface):
     for name, func in list(iface.__dict__.items()):
         if name == "__inherits__":
             continue
-        if isinstance(func, collections.Callable):
+        if isinstance(func, collections.abc.Callable):
             assert hasattr(klass, name), "Attribute %s missing from %r" % (name, klass)
             imp_func = getattr(klass, name)
-            imp_code = get_func_code(imp_func)
-            code = get_func_code(func)
+            imp_code = imp_func.__code__
+            code = func.__code__
             imp_nargs = imp_code.co_argcount
             nargs = code.co_argcount
             if imp_code.co_varnames[:imp_nargs] != code.co_varnames[:nargs]:
                 assert False, "Arguments of %s.%s differ from interface: " "%r!=%r" % (
                     klass.__name__,
-                    get_func_name(imp_func),
+                    imp_func.__name__,
                     imp_code.co_varnames[:imp_nargs],
                     code.co_varnames[:nargs],
                 )
@@ -288,11 +270,11 @@ class Timer(object):
     def tic(self, cat):
         """Starting timer"""
         print(">", cat)
-        self.t0_dict[cat] = time.clock()
+        self.t0_dict[cat] = time.perf_counter()
 
     def toc(self, cat, msg="delta:"):
         """Stopping timer"""
-        print("<", cat, ":", msg, time.clock() - self.t0_dict[cat])
+        print("<", cat, ":", msg, time.perf_counter() - self.t0_dict[cat])
 
 
 _TIMER = Timer()
@@ -332,6 +314,68 @@ def run_program(name, args="", cwd=None, shell=True, wait=False):
         subprocess.Popen(" ".join(command), cwd=cwd, shell=shell)
 
 
+class ProgramError(Exception):
+    """Exception raised when a shell command failed to execute."""
+
+    pass
+
+
+def alter_subprocess_kwargs_by_platform(**kwargs):
+    """
+    Given a dict, populate kwargs to create a generally
+    useful default setup for running subprocess processes
+    on different platforms. For example, `close_fds` is
+    set on posix and creation of a new console window is
+    disabled on Windows.
+
+    This function will alter the given kwargs and return
+    the modified dict.
+    """
+    kwargs.setdefault("close_fds", os.name == "posix")
+    if os.name == "nt":
+        CONSOLE_CREATION_FLAGS = 0  # Default value
+        # See: https://msdn.microsoft.com/en-us/library/windows/desktop/ms684863%28v=vs.85%29.aspx
+        CREATE_NO_WINDOW = 0x08000000
+        # We "or" them together
+        CONSOLE_CREATION_FLAGS |= CREATE_NO_WINDOW
+        kwargs.setdefault("creationflags", CONSOLE_CREATION_FLAGS)
+    return kwargs
+
+
+def run_shell_command(cmdstr, **subprocess_kwargs):
+    """
+    Execute the given shell command.
+
+    Note that *args and **kwargs will be passed to the subprocess call.
+
+    If 'shell' is given in subprocess_kwargs it must be True,
+    otherwise ProgramError will be raised.
+
+    If 'executable' is not given in subprocess_kwargs, it will
+    be set to the value of the SHELL environment variable.
+
+    Note that stdin, stdout and stderr will be set by default
+    to PIPE unless specified in subprocess_kwargs.
+
+    :str cmdstr: The string run as a shell command.
+    :subprocess_kwargs: These will be passed to subprocess.Popen.
+    """
+    if "shell" in subprocess_kwargs and not subprocess_kwargs["shell"]:
+        raise ProgramError(
+            'The "shell" kwarg may be omitted, but if ' "provided it must be True."
+        )
+    else:
+        subprocess_kwargs["shell"] = True
+
+    if "executable" not in subprocess_kwargs:
+        subprocess_kwargs["executable"] = os.getenv("SHELL")
+
+    for stream in ["stdin", "stdout", "stderr"]:
+        subprocess_kwargs.setdefault(stream, subprocess.PIPE)
+    subprocess_kwargs = alter_subprocess_kwargs_by_platform(**subprocess_kwargs)
+    return subprocess.Popen(cmdstr, **subprocess_kwargs)
+
+
 def is_module_available(module_name):
     """Return True if Python module is available"""
     try:
@@ -362,6 +406,26 @@ def getcwd_or_home():
         return get_home_dir()
 
 
+def remove_backslashes(path):
+    """Remove backslashes in *path*
+
+    For Windows platforms only.
+    Returns the path unchanged on other platforms.
+
+    This is especially useful when formatting path strings on
+    Windows platforms for which folder paths may contain backslashes
+    and provoke unicode decoding errors in Python 3 (or in Python 2
+    when future 'unicode_literals' symbol has been imported)."""
+    if os.name == "nt":
+        # Removing trailing single backslash
+        if path.endswith("\\") and not path.endswith("\\\\"):
+            path = path[:-1]
+        # Replacing backslashes by slashes
+        path = path.replace("\\", "/")
+        path = path.replace("/'", "\\'")
+    return path
+
+
 # ==============================================================================
 # Utilities for setup.py scripts
 # ==============================================================================
