@@ -9,12 +9,15 @@
 # -----------------------------------------------------------------------------
 
 """
-Pandas DataFrame Editor Dialog.
+guidata.widgets.dataframeeditor
+===============================
 
-DataFrameModel is based on the class ArrayModel from array editor
+This package provides a DataFrameModel based on the class ArrayModel from array editor
 and the class DataFrameModel from the pandas project.
 Present in pandas.sandbox.qtpandas in v0.13.1.
 
+.. autoclass:: DataFrameEditor
+
 Originally based on pandas/sandbox/qtpandas.py of the
 `pandas project <https://github.com/pandas-dev/pandas>`_.
 The current version is qtpandas/models/DataFrameModel.py of the
@@ -31,6 +34,7 @@ from guidata.qthelpers import (
     add_actions,
     create_action,
     keybinding,
+    win32_fix_title_bar_background,
 )
 from guidata.config import CONF, _
 from qtpy.QtWidgets import (
@@ -735,6 +739,7 @@ class DataFrameEditor(QDialog):
 
     def __init__(self, parent=None):
         QDialog.__init__(self, parent)
+        win32_fix_title_bar_background(self)
         # Destroying the C++ object right after closing the dialog box,
         # otherwise it may be garbage-collected in another QThread
         # (e.g. the editor's analysis thread in Spyder), thus leading to
